aboutsummaryrefslogtreecommitdiff
path: root/www/chromium/files/patch-chrome_browser_ui_views_frame_browser__frame.cc
diff options
context:
space:
mode:
authorRobert Nagy <robert@openbsd.org>2022-10-25 11:16:46 +0000
committerRene Ladan <rene@FreeBSD.org>2022-10-27 13:08:22 +0000
commit74a0f0ebf0c472210e0676fd723d36397f679cc0 (patch)
tree82919a814aa92dc17bfceffa1a07c1f35b26e5d2 /www/chromium/files/patch-chrome_browser_ui_views_frame_browser__frame.cc
parent427a15a973365496da3b18eb3794848e8b39ba0c (diff)
downloadports-74a0f0ebf0c472210e0676fd723d36397f679cc0.tar.gz
ports-74a0f0ebf0c472210e0676fd723d36397f679cc0.zip
www/chromium: update to 107.0.5304.68
Diffstat (limited to 'www/chromium/files/patch-chrome_browser_ui_views_frame_browser__frame.cc')
-rw-r--r--www/chromium/files/patch-chrome_browser_ui_views_frame_browser__frame.cc53
1 files changed, 24 insertions, 29 deletions
diff --git a/www/chromium/files/patch-chrome_browser_ui_views_frame_browser__frame.cc b/www/chromium/files/patch-chrome_browser_ui_views_frame_browser__frame.cc
index b2768b8cc274..2ebc56223367 100644
--- a/www/chromium/files/patch-chrome_browser_ui_views_frame_browser__frame.cc
+++ b/www/chromium/files/patch-chrome_browser_ui_views_frame_browser__frame.cc
@@ -1,52 +1,47 @@
---- chrome/browser/ui/views/frame/browser_frame.cc.orig 2022-08-31 12:19:35 UTC
+--- chrome/browser/ui/views/frame/browser_frame.cc.orig 2022-10-24 13:33:33 UTC
+++ chrome/browser/ui/views/frame/browser_frame.cc
-@@ -49,11 +49,11 @@
-
- // TODO(crbug.com/1052397): Revisit the macro expression once build flag switch
- // of lacros-chrome is complete.
--#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS_LACROS)
-+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS_LACROS) || BUILDFLAG(IS_BSD)
- #include "ui/display/screen.h"
+@@ -46,7 +46,7 @@
+ #include "components/user_manager/user_manager.h"
#endif
-#if BUILDFLAG(IS_LINUX)
+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_BSD)
+ #include "ui/display/screen.h"
#include "ui/linux/linux_ui.h"
#endif
+@@ -54,7 +54,7 @@
+ namespace {
-@@ -62,7 +62,7 @@ namespace {
- bool IsUsingGtkTheme(Profile* profile) {
- // TODO(crbug.com/1052397): Revisit the macro expression once build flag switch
- // of lacros-chrome is complete.
--#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS_LACROS)
-+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS_LACROS) || BUILDFLAG(IS_BSD)
+ bool IsUsingLinuxSystemTheme(Profile* profile) {
+-#if BUILDFLAG(IS_LINUX)
++#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_BSD)
return ThemeServiceFactory::GetForProfile(profile)->UsingSystemTheme();
#else
return false;
-@@ -279,7 +279,7 @@ void BrowserFrame::OnNativeWidgetWorkspaceChanged() {
+@@ -269,7 +269,7 @@ void BrowserFrame::OnNativeWidgetWorkspaceChanged() {
+ chrome::SaveWindowWorkspace(browser_view_->browser(), GetWorkspace());
+ chrome::SaveWindowVisibleOnAllWorkspaces(browser_view_->browser(),
IsVisibleOnAllWorkspaces());
- // TODO(crbug.com/1052397): Revisit the macro expression once build flag switch
- // of lacros-chrome is complete.
--#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS_LACROS)
-+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS_LACROS) || BUILDFLAG(IS_BSD)
+-#if BUILDFLAG(IS_LINUX)
++#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_BSD)
// If the window was sent to a different workspace, prioritize it if
// it was sent to the current workspace and deprioritize it
// otherwise. This is done by MoveBrowsersInWorkspaceToFront()
-@@ -402,7 +402,7 @@ void BrowserFrame::SelectNativeTheme() {
+@@ -392,7 +392,7 @@ void BrowserFrame::SelectNativeTheme() {
return;
}
-#if BUILDFLAG(IS_LINUX)
+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_BSD)
- const ui::LinuxUi* linux_ui = ui::LinuxUi::instance();
- // Ignore GTK+ for web apps with window-controls-overlay as the
- // display_override so the web contents can blend with the overlay by using
-@@ -421,7 +421,7 @@ bool BrowserFrame::RegenerateFrameOnThemeChange(
+ const auto* linux_ui_theme =
+ ui::LinuxUiTheme::GetForWindow(GetNativeWindow());
+ // Ignore the system theme for web apps with window-controls-overlay as the
+@@ -409,7 +409,7 @@ void BrowserFrame::SelectNativeTheme() {
+ bool BrowserFrame::RegenerateFrameOnThemeChange(
+ BrowserThemeChangeType theme_change_type) {
bool need_regenerate = false;
- // TODO(crbug.com/1052397): Revisit the macro expression once build flag
- // switch of lacros-chrome is complete.
--#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS_LACROS)
-+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS_LACROS) || BUILDFLAG(IS_BSD)
- // GTK and user theme changes can both change frame buttons, so the frame
+-#if BUILDFLAG(IS_LINUX)
++#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_BSD)
+ // System and user theme changes can both change frame buttons, so the frame
// always needs to be regenerated on Linux.
need_regenerate = true;